=========
Astro Pi HAT
=========

Python module to control the Astro Pi HAT for the `Raspberry Pi`_ used in the `Astro Pi`_ mission - an education outreach programme for UK schools sending code experiments to the International Space Station.


.. _Raspberry Pi: http://www.raspberrypi.org/
.. _Astro Pi: http://www.astro-pi.org/
